==> 5.7.7.zip: 5.7.7/engine/Shopware/Bundle/StoreFrontBundle/Gateway/ShopPageChildrenGatewayInterface.php <==
<?php
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

namespace Shopware\Bundle\StoreFrontBundle\Gateway;

use Shopware\Bundle\StoreFrontBundle\Struct;

interface ShopPageChildrenGatewayInterface
{
    /**
     * The \Shopware\Bundle\StoreFrontBundle\Struct\ShopPage requires the following data:
     * - shop page data
     * - Core attribute of the shop page
     *
     * Required translation in the provided context language:
     * - Shop page
     *
     * @param int[] $ids
     *
     * @return Struct\ShopPage[] Indexed by the shop page id
     */
    public function getList(array $ids, Struct\ShopContextInterface $context);
}

==> 5.7.14.zip: 5.7.14/engine/Shopware/Bundle/StoreFrontBundle/Gateway/ShopPageChildrenGatewayInterface.php <==
<?php
/**
 * Shopware 5
 * Copyright (c) shopware AG
 *
 * According to our dual licensing model, this program can be used either
 * under the terms of the GNU Affero General Public License, version 3,
 * or under a proprietary license.
 *
 * The texts of the GNU Affero General Public License with an additional
 * permission and of our proprietary license can be found at and
 * in the LICENSE file you have received along with this program.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero General Public License for more details.
 *
 * "Shopware" is a registered trademark of shopware AG.
 * The licensing of the program under the AGPLv3 does not imply a
 * trademark license. Therefore any rights, title and interest in
 * our trademarks remain entirely with us.
 */

namespace Shopware\Bundle\StoreFrontBundle\Gateway;

use Shopware\Bundle\StoreFrontBundle\Struct\ShopContextInterface;
use Shopware\Bundle\StoreFrontBundle\Struct\ShopPage;

interface ShopPageChildrenGatewayInterface
{
    /**
     * The \Shopware\Bundle\StoreFrontBundle\Struct\ShopPage requires the following data:
     * - shop page data
     * - Core attribute of the shop page
     *
     * Required translation in the provided context language:
     * - Shop page
     *
     * @param int[] $ids
     *
     * @return array<int, ShopPage> Indexed by the shop page id
     */
    public function getList(array $ids, ShopContextInterface $context);
}
